Name: screen
Version: 4.0.2
Release: alt1

Summary: A screen manager that supports multiple sessions on one terminal
License: GPL
Group: Terminals
Url: http://www.gnu.org/software/%name

# Do we want to generate and install several terminfo entries (screen*)?
# In fact, they are counterparts of that ones that are now included in ncurses.
%def_without terminfo

# ftp://ftp.gnu.org/gnu/screen/
# ftp://ftp.uni-erlangen.de/pub/utilities/screen/
Source: %name-%version.tar.bz2
Source1: %name.pamd
Source2: %name-ALT-PACKAGING-INFO.en

# May be needed only by packager
Source3: %name-search-dot-screen.sh

Source4: screen4-deb-faq
Source5: screen4-screenrc
Source6: screen4-screencap

# Provide correct info direntry (this patch is version-dependent)
Patch1: %name-%version-alt-texinfo.patch

# Correct bugs in documentaion (so that it reflects the real behaviour)
Patch2: %name-3.9.11-alt-docbug-closeall.patch
Patch3: %name-3.9.11-alt-docbug-hardcopy.patch

# Adds the lines about SIGCHLD-behaviour to the docs
Patch4: %name-3.9.11-alt-doc-sigchld.patch

# backspace/delete hack for sample screenrc
Patch5: %name-4.0.2-rh-delete-hack.patch

Patch11: %name-3.7.6-mdk-compat21.patch
Patch12: %name-3.9.5-rh-ia64.patch
Patch13: %name-3.9.8-alt-osdef.patch

Patch15: %name-3.9.11-deb-owl-alt-pty.patch
Patch16: %name-3.9.15-alt-owl-config.patch
Patch17: %name-3.9.11-owl-alt-telnet.patch
Patch18: %name-3.9.15-deb-owl-alt-home-screen-exchange.patch

# Fixes paths in Makefile for terminfo
Patch19: %name-3.9.9-alt-terminfo.patch

# Makes "~/tmp/screen" the default directory for user's sockets
# (best used with ./configure --disable-socket-dir)
Patch20: %name-3.9.11-alt-another-sockdir.patch

Patch21: %name-3.9.10-owl-tmp.patch
Patch22: %name-3.9.15-alt-msgfix.patch

# Use new utempter interface.
Patch23: %name-3.9.11-alt-utempter.patch

# Use pam_usermode; switch egid for the PAM authentication.
Patch24: %name-4.0.2-owl-pam.patch

# Don't compile in the SIGSEGV/SIGBUS fault handler.
Patch25: %name-4.0.2-owl-no-fault-handler.patch

# Fix utf8encodings path.
Patch26: %name-3.9.11-alt-install.patch

# http://securityfocus.com/archive/1/345844
# http://cve.mitre.org/cgi-bin/cvename.cgi?name=CAN-2003-0972
Patch27: %name-3.9.15-tss-buffer-overflow.patch

# Make -Werror possible.
Patch28: %name-4.0.2-owl-warnings.patch

Requires(pre): shadow-utils
Requires(post): libutempter >= 1.0.6, pam_tcb >= 0.9.7.1, coreutils

Requires(post): %install_info
Requires(preun): %uninstall_info

BuildPreReq: libutempter-devel >= 1.0.6
%{?_with_terminfo:BuildPreReq: ncurses}

# Automatically added by buildreq on Tue Sep 09 2003
BuildRequires: libncurses-devel libpam0-devel libutempter-devel pam_userpass-devel

%description
The %name utility allows you to run interactive text-mode programs
(such as login shells) even if it is not possible to control them
interactively all the time (for example, because you are limited by
the way of access to a remote machine.)

For instance, you can do several interactive tasks on the same
physical terminal (a remote shell session) by switching from one virtual
terminal to another with the help of %name utility installed on the
remote machine. Another option would be running a program that needs a
terminal without attaching it to any physical terminal at all
(its start may be scheduled in crontab, or you may want to detach it
when you break the connection to the remote machine).

Install the %name package if you may need to use virtual terminals
managed by the %name utility.

%prep
%setup -q
%__install -m644 %SOURCE4 FAQ.Debian

# Remove all junk (we'll regenerate these files later):
%__rm -f configure doc/*.info*

# First, patch the docs:

# Make corrections to the docs (and some other files):
find doc -type f -print0 |
	xargs -r0 %__grep -FZl /usr/local/etc/screenrc -- |
	xargs -r0 %__subst -p 's|/usr/local/etc/screenrc|%_sysconfdir/screenrc|' -- etc/etcscreenrc
find doc -type f -print0 |
	xargs -r0 %__grep -FZl /local/etc/screenrc -- |
	xargs -r0 %__subst -p 's|/local/etc/screenrc|%_sysconfdir/screenrc|' --
find doc -type f -print0 |
	xargs -r0 %__grep -FZl /etc/utmp -- |
	xargs -r0 %__subst -p 's|/etc/utmp|/var/run/utmp|' -- os.h

%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1

# The docs corrected, now the REAL patches
%patch11 -p1
%patch12 -p1
%patch13 -p1

%patch15 -p1
%patch16 -p1
%patch17 -p1
%patch18 -p1
%patch19 -p1

%patch20 -p1
%patch21 -p1
%patch22 -p1
%patch23 -p1
%patch24 -p1
%patch25 -p1
%patch26 -p1
%patch27 -p1
%patch28 -p1

srcdir="${PWD##*/}"
pushd ..
sh %SOURCE3 --check "$srcdir"
popd
unset srcdir

%build
autoconf
%add_optflags -D_GNU_SOURCE
%configure \
	--with-sys-screenrc=%_sysconfdir/screenrc \
	--disable-socket-dir \
	--enable-pam \
	--enable-telnet \
	--enable-colors256 \
	--enable-rxvt_osc

# Does it work at all?
#%__perl -pi -e 's|.*#undef HAVE_BRAILLE.*|#define HAVE_BRAILLE 1|' config.h

%make_build CFLAGS="%optflags -Werror"
%__bzip2 -9 doc/*.ps

%install
%if_with terminfo
%__mkdir_p %buildroot%_datadir/terminfo
%endif

%makeinstall

pushd %buildroot%_bindir
	%__rm -f %name.old %name
	%__mv %name-%version %name
popd

%__install -pD -m644 %SOURCE5 %buildroot%_sysconfdir/screenrc
%__install -pD -m644 %SOURCE6 %buildroot%_sysconfdir/screencap

%__install -pD -m644 %SOURCE1 $RPM_BUILD_ROOT%_sysconfdir/pam.d/%name

%__mkdir_p %buildroot%_libexecdir/%name
touch %buildroot%_libexecdir/%name/{tcb_chkpwd,utempter}

# Move some docs around. (Put our packaging info here for including it
# in the %%doc section.)
%__install -p -m644 %SOURCE2 ALT-PACKAGING-INFO.en

%pre
/usr/sbin/groupadd -r -f %name >/dev/null 2>&1

%post
/bin/ln -f %_libexecdir/chkpwd/tcb_chkpwd %_libexecdir/%name/
/bin/ln -f %_libexecdir/utempter/utempter %_libexecdir/%name/
%install_info %name.info
if [ -d /tmp/screens ]; then
	# We're not setuid root anymore.
	chmod 000 /tmp/screens
	echo 'Time to fix /tmp/screens'
fi

%preun
%uninstall_info %name.info

%triggerin -- pam_tcb >= 0.9.7.1
/bin/ln -f %_libexecdir/chkpwd/tcb_chkpwd %_libexecdir/%name/

%triggerin -- libutempter >= 1.0.6
/bin/ln -f %_libexecdir/utempter/utempter %_libexecdir/%name/

%files
%attr(2711,root,%name) %_bindir/%name
%attr(710,root,%name) %dir %_libexecdir/%name
%attr(2711,root,shadow) %ghost %_libexecdir/%name/tcb_chkpwd
%attr(2711,root,utmp) %ghost %_libexecdir/%name/utempter

%_datadir/%name
%_man1dir/%name.*
%_infodir/*.info*
%config(noreplace) %_sysconfdir/screenrc
%config(noreplace) %_sysconfdir/screencap
%config(noreplace) %_sysconfdir/pam.d/%name

%if_with terminfo
%_datadir/terminfo/*
%endif

# The sample ~/.screenrc file, I see no reason for putting it into
# /etc/skel/: let alone the fact that it would be never used because
# usually the localized varinats of /etc/skel/ are used.
%doc etc/*screenrc
%doc NEWS README FAQ doc/README.DOTSCREEN doc/*.ps.*
%doc FAQ.Debian
%doc ALT-PACKAGING-INFO*

%changelog
* Thu Jan 15 2004 Alexey Tourbin <at@altlinux.ru> 4.0.2-alt1
- 4.0.2 (new screenrc parser, see NEWS)
- configuration file reworked
  + moved terminal settings to /etc/screencap (sourced from screenrc)
- rh-delete-hack.patch (treat backspaces '^?' as deletes in sample screenrc)
- owl-pam.patch and owl-no-fault-handler.patch updated
- owl-warnings patch applied, -Werror mode enabled
- support for rxvt OSC codes enabled
- removed "merge status" from specfile as it is completely outdated
- added Debian FAQ

* Fri Nov 28 2003 Alexey Tourbin <at@altlinux.ru> 3.9.15-alt2
- security update (buffer overflow fixed, Timo Sirainen)

* Fri Sep 05 2003 Alexey Tourbin <at@altlinux.ru> 3.9.15-alt1.1
- alt-owl-config.patch updated (eliminates glibc-devel-static from BuildRequires)
- support for 256 colors enabled

* Sun Aug 03 2003 Alexey Tourbin <at@altlinux.ru> 3.9.15-alt1
- 3.9.15; patches updated: alt-texinfo, alt-owl-config,
  deb-owl-alt-home-screen-exchange, alt-msgfix, alt-owl-pam,
  owl-alt-no-fault-handler, mdk-alt-max-window-size

* Sat Apr 12 2003 Dmitry V. Levin <ldv@altlinux.org> 3.9.11-alt4
- Rebuilt with libpam_userpass.so.1.

* Tue Dec 24 2002 Dmitry V. Levin <ldv@altlinux.org> 3.9.11-alt3
- Rebuilt with libutempter-1.1.0.

* Tue Nov 05 2002 Dmitry V. Levin <ldv@altlinux.org> 3.9.11-alt2
- Use subst instead of perl in %%build.

* Sun May 26 2002 Dmitry V. Levin <ldv@altlinux.org> 3.9.11-alt1
- 3.9.11, updated patches.
- Dropped screen terminfo entries (can be found in terminfo package).
- Grant screen access to both chkpwd and utempter helpers via a group
  screen restricted directory and hard links (Owl).
- Switch egid for the PAM authentication making use of POSIX saved ID's (Owl).
- Don't compile in the SIGSEGV/SIGBUS fault handler; previously it was
  only used for SUID installation, not SGID, and would claim to dump core
  which it indeed can't do (Owl).
- Updated dependencies.

* Mon Dec 17 2001 Dmitry V. Levin <ldv@alt-linux.org> 3.9.10-alt4
- Reordered patches.
- Fixed message typo in FindSocket().
- More tmp fixes in configure.in (Owl).
- Added pam_userpass support (derived from Owl's patch).
- Link without libelf and libshadow.

* Mon Oct 15 2001 Dmitry V. Levin <ldv@alt-linux.org> 3.9.10-alt3
- Patched and built with new utempter.

* Thu Oct 11 2001 Dmitry V. Levin <ldv@altlinux.ru> 3.9.10-alt2
- Made %_bindir/%name sgid to utempter.

* Mon Sep 10 2001 Dmitry V. Levin <ldv@altlinux.ru> 3.9.10-alt1
- 3.9.10

* Sat Jul  7 2001 Ivan Zakharyaschev <imz@altlinux.ru> 3.9.9-alt3
- the default place for user's sockets is now ~/tmp/screen/
- Files:
  + /etc/profile.d/screen.sh thrown away (it made using screen almost
    impossible)
  + added ALT-PACKAGING-INFO.en
- Documentation: a useful addition about the resurrecting effect of
  SIGCHLD.
- spec-file:
  + the args for %%make_build became shorter (no need to define
    ETCSCREENRC -- it is passed in ./configure options)
  + generating and installing terminfo entries made optional

* Thu Jun 28 2001 Ivan Zakharyaschev <imz@altlinux.ru> 3.9.9-alt2
- Files:
    + the sample user's .screenrc moved from /etc/skel/ to doc
    + terminfo files included (the same files provided by ncurses
      package are just counterparts of these ones).
- Documentation fixes from RedHat.
- Changes in the spec-file (all of them don't affect the content of the
resulting binary package):
  + made the Description a bit less lamer-ish
  + other minor enhancements
  + some substitution commands thrown away from %%build section because
    the same corrections are done in the Owl's patches
  + shortened a bit Owl's config patch -- the same configuration is done
    by adding ./configure options.

* Mon May 28 2001 Stanislav Ievlev <inger@altlinux.ru> 3.9.9-alt1
- 3.9.9

* Thu May 17 2001 Stanislav Ievlev <inger@altlinux.ru> 3.9.8-ipl2mdk
- Add patches from Owl.

* Wed Nov 15 2000 Dmitry V. Levin <ldv@fandra.org> 3.9.8-ipl1mdk
- 3.9.8
- Patched to build with glibc-2.2.

* Wed Sep 20 2000 Dmitry V. Levin <ldv@fandra.org> 3.9.5-ipl9mdk
- RE adaptions.
- Automatically added BuildRequires.

* Mon Sep 18 2000 Francis Galiegue <fg@mandrakesoft.com> 3.9.5-9mdk
- Fix info file

* Fri Sep 15 2000 Francis Galiegue <fg@mandrakesoft.com> 3.9.5-8mdk
- Security fix, adapted patch from RH

* Mon Aug 07 2000 Frederic Lepied <flepied@mandrakesoft.com> 3.9.5-7mdk
- automatically added BuildRequires

* Fri Jul 28 2000 Francis Galiegue <fg@mandrakesoft.com> 3.9.5-6mdk
- Oops... Fixed *info macros...

* Fri Jul 28 2000 Francis Galiegue <fg@mandrakesoft.com> 3.9.5-5mdk
- BMacros
- Some spec file changes

* Mon Jun 26 2000 Thierry Vignaud <tvignaud@mandrakesoft.com> 3.9.5-4mdk
- fix wrong URL
- use %%_mandir & %%_infodir to prepare FHS compliancy
- merge in RH patches

* Sun Jun 04 2000 David BAUDENS <baudens@mandrakesoft.com> 3.9.5-3mdk
- Fix build

* Fri Mar 17 2000 Francis Galiegue <francis@mandrakesoft.com>
- Let spec helper handle stripping and compressed manpages
- Changed group to match 7.1 specs

* Tue Dec 21 1999 Chmouel Boudjnah <chmouel@mandrakesoft.com>
- 3.9.5 (fix a lot of know bugs).

* Wed Nov 10 1999 Francis Galiegue <francis@mandrakesoft.com>
- Really fixed /etc/skel/.screenrc permissions
- Fixed /etc/screenrc permissions
- spawn ptys are no more world writable

* Tue Nov 09 1999 John Buswell <johnb@mandrakesoft.com>
- Fixed /etc/skel/.screenrc permissions
- Enabled Unix98 ptys

* Tue Nov 02 1999 John Buswell <johnb@mandrakesoft.com>
- Build Release

* Thu Oct 21 1999 Francis Galiegue <francis@mandrakesoft.com>
- Merged patch from RedHat: screen now uses /dev/pts/*
- made /etc/profile.d/screen.sh sh-compatible (use test -z $SCREENDIR)

* Tue Sep 21 1999 Francis Galiegue <francis@mandrakesoft.com>
- fixed bug in /etc/profile.d/screen.sh (credits go to Axalon for this one)

* Mon Aug 23 1999 Thierry Vignaud <tvignaud@mandrakesoft.com>
- 3.9.4

* Sun Jul 25 1999 Axalon Bloodstone <axalon@linux-mandrake.com>
- set SCREENDIR=$HOME/tmp

* Tue May 11 1999 Chmouel Boudjnah <chmouel@mandrakesoft.com>
- Mandrake adaptations.

* Wed Apr 07 1999 Bill Nottingham <notting@redhat.com>
- take out warning of directory ownership so root can still use screen

* Wed Apr 07 1999 Erik Troan <ewt@redhat.com>
- patched in utempter support, turned off setuid bit

* Fri Mar 26 1999 Erik Troan <ewt@redhat.com>
- fixed unix98 pty support

* Sun Mar 21 1999 Cristian Gafton <gafton@redhat.com>
- auto rebuild in the new build environment (release 3)

* Thu Mar 11 1999 Bill Nottingham <notting@redhat.com>
- add patch for Unix98 pty support

* Mon Dec 28 1998 Jeff Johnson <jbj@redhat.com>
- update to 3.7.6.

* Sun Aug 16 1998 Jeff Johnson <jbj@redhat.com>
- build root

* Mon Apr 27 1998 Prospector System <bugs@redhat.com>
- translations modified for de, fr, tr

* Wed Oct 21 1997 Cristian Gafton <gafton@redhat.com>
- upgraded to 3.7.4

* Wed Oct 08 1997 Erik Troan <ewt@redhat.com>
- removed glibc 1.99 specific patch

* Tue Sep 23 1997 Erik Troan <ewt@redhat.com>
- added install-info support

* Mon Jul 21 1997 Erik Troan <ewt@redhat.com>
- built against glibc
